==> rtl8821ce_5.2.5.2.1.30816.20190425.orig.tar.xz: rtl8821ce-5.2.5.2.1.30816.20190425/hal/phydm/rtl8821c/halphyrf_8821c.h <==
/* SPDX-License-Identifier: GPL-2.0 */
/******************************************************************************
 *
 * Copyright(c) 2007 - 2011 Realtek Corporation. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
 *
 *
 ******************************************************************************/

#ifndef __HAL_PHY_RF_8821C_H__
#define __HAL_PHY_RF_8821C_H__

#define AVG_THERMAL_NUM_8821C	4
#define RF_T_METER_8821C		0x42

void configure_txpower_track_8821c(
	struct _TXPWRTRACK_CFG	*p_config
);

void
odm_tx_pwr_track_set_pwr8821c(
	void				*p_dm_void,
	enum pwrtrack_method	method,
	u8				rf_path,
	u8				channel_mapped_index
);

void
get_delta_swing_table_8821c(
	void		*p_dm_void,
	u8 **temperature_up_a,
	u8 **temperature_down_a,
	u8 **temperature_up_b,
	u8 **temperature_down_b
);

void
phy_lc_calibrate_8821c(
	void *p_dm_void
);

void phy_set_rf_path_switch_8821c(
	struct _ADAPTER	*p_adapter,
	boolean		is_main
);

boolean phy_query_rf_path_switch_8821c(
	struct _ADAPTER	*p_adapter
);

#endif	/* #ifndef __HAL_PHY_RF_8821C_H__ */

==> rtl8821ce_5.5.2.orig.tar.xz: rtl8821ce-5.5.2/hal/phydm/rtl8821c/halphyrf_8821c.h <==
/******************************************************************************
 *
 * Copyright(c) 2007 - 2011 Realtek Corporation. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
 *
 *
 ******************************************************************************/

#ifndef __HAL_PHY_RF_8821C_H__
#define __HAL_PHY_RF_8821C_H__

#define AVG_THERMAL_NUM_8821C	4
#define RF_T_METER_8821C		0x42

void configure_txpower_track_8821c(
	struct _TXPWRTRACK_CFG	*p_config
);

void
odm_tx_pwr_track_set_pwr8821c(
	void				*p_dm_void,
	enum pwrtrack_method	method,
	u8				rf_path,
	u8				channel_mapped_index
);

void
get_delta_swing_table_8821c(
	void		*p_dm_void,
#if (DM_ODM_SUPPORT_TYPE & ODM_AP)
	u8 **temperature_up_a,
	u8 **temperature_down_a,
	u8 **temperature_up_b,
	u8 **temperature_down_b,
	u8 **temperature_up_cck_a,
	u8 **temperature_down_cck_a,
	u8 **temperature_up_cck_b,
	u8 **temperature_down_cck_b
#else
	u8 **temperature_up_a,
	u8 **temperature_down_a,
	u8 **temperature_up_b,
	u8 **temperature_down_b
#endif
);

void
phy_lc_calibrate_8821c(
	void *p_dm_void
);



void phy_set_rf_path_switch_8821c(
#if (DM_ODM_SUPPORT_TYPE & ODM_AP)
	struct PHY_DM_STRUCT		*p_dm_odm,
#else
	struct _ADAPTER	*p_adapter,
#endif
	boolean		is_main
);

boolean phy_query_rf_path_switch_8821c(
#if (DM_ODM_SUPPORT_TYPE & ODM_AP)
	struct PHY_DM_STRUCT	*p_dm_odm,
#else
	struct _ADAPTER	*p_adapter
#endif
);

#endif	/* #ifndef __HAL_PHY_RF_8821C_H__ */
